@@ -1,4 +1,4 @@
-package Pod::Weaver::Section::Version 4.019;
+package Pod::Weaver::Section::Version 4.020;
 # ABSTRACT: add a VERSION pod section
 
 use Moose;
@@ -41,7 +41,24 @@ has header => (
 );
 
 use DateTime;
-use Moose::Util::TypeConstraints;
+
+{
+  # This is irritating.
+  #
+  # Moose::Util::TypeConstraints will turn on strict and warnings.  This will
+  # undermine the setup that "use experimental" did above.  So I could move
+  # this above my boilerplate pragmata.  But this is annoying too, where the
+  # order of libraries is based on largely invisible factors.  I now believe
+  # that "Moose stuff turns on strict!" was a mistake, even if a
+  # well-intentioned one.  So it goes.
+  #
+  # So, I'm putting it in a block.  Why?  Because the "use strict" that gets
+  # exported is *lexical* and so will be constrained by this block.  The named
+  # subroutines, though, are *global* so they will still work.
+  #
+  # Can't push me around, perl! -- rjbs, 2024-03-21
+  use Moose::Util::TypeConstraints;
+}
 
 my $MARKER;
 BEGIN { $MARKER = "\x{2316}" }
@@ -263,7 +280,7 @@ Pod::Weaver::Section::Version - add a VERSION pod section
 
 =head1 VERSION
 
-version 4.019
+version 4.020
 
 =head1 OVERVIEW
 
@@ -279,14 +296,15 @@ It will do nothing if there is no C<version> entry in the input.
 =head1 PERL VERSION
 
 This module should work on any version of perl still receiving updates from
-the Perl 5 Porters.  This means it should work on any version of perl released
-in the last two to three years.  (That is, if the most recently released
-version is v5.40, then this module should work on both v5.40 and v5.38.)
+the Perl 5 Porters.  This means it should work on any version of perl
+released in the last two to three years.  (That is, if the most recently
+released version is v5.40, then this module should work on both v5.40 and
+v5.38.)
 
 Although it may work on older versions of perl, no guarantee is made that the
 minimum required version will not be increased.  The version may be increased
-for any reason, and there is no promise that patches will be accepted to lower
-the minimum required perl.
+for any reason, and there is no promise that patches will be accepted to
+lower the minimum required perl.
 
 =head1 ATTRIBUTES
 
@@ -387,7 +405,7 @@ Ricardo SIGNES <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2023 by Ricardo SIGNES.
+This software is copyright (c) 2024 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
